"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DB2BaseHandler = void 0;
const imperative_1 = require("@zowe/imperative");
const DB2Session_1 = require("./DB2Session");
/**
 * This class is used by the various DB2 handlers as the base class for their implementation.
 * All handlers should extend this class whenever possible
 */
class DB2BaseHandler {
    /**
     * This will create a session before calling the subclass
     *
     * @param {IHandlerParameters} commandParameters Command parameters sent by imperative.
     *
     * @returns {Promise<void>}
     */
    process(commandParameters) {
        return __awaiter(this, void 0, void 0, function* () {
            this.mHandlerParams = commandParameters;
            const session = yield DB2Session_1.DB2Session.createSessCfgFromArgs(commandParameters.arguments, true, commandParameters);
            try {
                yield this.processWithDB2Session(commandParameters, session);
            }
            catch (err) {
                if (err instanceof imperative_1.ImperativeError) {
                    throw err;
                }
                else {
                    throw new imperative_1.ImperativeError({ msg: err.message, causeErrors: err });
                }
            }
        });
    }
}
exports.DB2BaseHandler = DB2BaseHandler;
//# sourceMappingURL=DB2BaseHandler.js.map